==> haskell-errors-2.3.0-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 errors
version:              2.3.0
visibility:           public
id:                   errors-2.3.0-FhBmHY7sMIf8wTT2E4ozOx
key:                  errors-2.3.0-FhBmHY7sMIf8wTT2E4ozOx
license:              BSD-3-Clause
copyright:            2012, 2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".

    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.

category:             Control, Error Handling
abi:                  ddda54e3eaf3f6b0885a6cabf0a8f858
exposed:              True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR

import-dirs:          /usr/lib/ghc-9.0.1/site-local/errors-2.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/errors-2.3.0
hs-libraries:         HSerrors-2.3.0-FhBmHY7sMIf8wTT2E4ozOx
depends:
    base-4.15.0.0 exceptions-0.10.4 safe-0.3.19-BCcHjTM7bV690cTfMWPidj
    text-1.2.4.1 transformers-0.5.6.2
    transformers-compat-0.7.1-27E2wCklav6CMkj1Ns7rzE

haddock-interfaces:   /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html:         /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.3.0-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 errors
version:              2.3.0
visibility:           public
id:                   errors-2.3.0-AMf4swi6TfI2g0Jb1DBx7t
key:                  errors-2.3.0-AMf4swi6TfI2g0Jb1DBx7t
license:              BSD-3-Clause
copyright:            2012, 2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".

    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.

category:             Control, Error Handling
abi:                  d71b851592c200d52ad053ffcf8b443d
exposed:              True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR

import-dirs:          /usr/lib/ghc-9.0.2/site-local/errors-2.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/errors-2.3.0
hs-libraries:         HSerrors-2.3.0-AMf4swi6TfI2g0Jb1DBx7t
depends:
    base-4.15.1.0 exceptions-0.10.4 safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q
    text-1.2.5.0 transformers-0.5.6.2
    transformers-compat-0.7.1-5G5J9BcZIFIGkjABObiUpP

haddock-interfaces:   /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html:         /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
